# Table of Contents

- [for-application-and-business-owners](<./for-application-and-business-owners.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [SAP LeanIX for Application and Business Owners](<./SAP-LeanIX-for-Application-and-Business-Owners.md>)
  - [Access the Workspace](<./SAP-LeanIX-for-Application-and-Business-Owners/Access-the-Workspace.md>)
  - [Find Information from Fact Sheets](<./SAP-LeanIX-for-Application-and-Business-Owners/Find-Information-from-Fact-Sheets.md>)
  - [Contribute Data to Fact Sheets](<./SAP-LeanIX-for-Application-and-Business-Owners/Contribute-Data-to-Fact-Sheets.md>)
  - [Next Steps](<./SAP-LeanIX-for-Application-and-Business-Owners/Next-Steps.md>)
